AttachmentLimitReachedError class
Returned by StreamAttachmentValidator.validateCount when the attachment count exceeds StreamAttachmentValidator.maxAttachmentCount.
See also:
- AttachmentTooLargeError, AttachmentBlockedError, for the other validator failures.
- Inheritance
-
- Object
- StreamChatError
- AttachmentLimitReachedError
Constructors
- AttachmentLimitReachedError({required int maxCount})
-
Creates a new AttachmentLimitReachedError.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCount → int
-
The maximum number of attachments allowed in a single message.
final
- message → String
-
A human-readable description of what went wrong.
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited