AttachmentTooLargeError class

Returned by StreamAttachmentValidator.validate when an attachment exceeds the per-category UploadConfig.sizeLimit.

See also:

Inheritance

Constructors

AttachmentTooLargeError({required int fileSize, required int maxSize})
Creates a new AttachmentTooLargeError.
const

Properties

fileSize int
The size of the attachment, in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
maxSize int
The maximum upload size, in bytes.
final
message String
A human-readable description of what went wrong.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited