truncate method
Removes all messages from the channel up to truncatedAt or now if
truncatedAt is not provided.
If skipPush is true, no push notification will be sent.
Message is the system message that will be sent to the channel.
Implementation
Future<EmptyResponse> truncate({
Message? message,
bool? skipPush,
DateTime? truncatedAt,
}) async {
_checkInitialized();
return _client.truncateChannel(
id!,
type,
message: message,
skipPush: skipPush,
truncatedAt: truncatedAt,
);
}