itemBuilder property
A builder that is called to build items in the PagedValueGridView.
The value parameter is the V at this position in the list.
Implementation
final PagedValueScrollViewIndexedWidgetBuilder<V> itemBuilder;
A builder that is called to build items in the PagedValueGridView.
The value parameter is the V at this position in the list.
final PagedValueScrollViewIndexedWidgetBuilder<V> itemBuilder;