StreamChannelAvatar class

A circular avatar component for displaying a channel's image.

StreamChannelAvatar displays a channel's image or an appropriate fallback based on the channel type. It supports channel images, user avatars for 1-1 conversations, and group avatars for multi-member channels.

The avatar automatically handles:

  • Reactive updates when channel image changes via Channel.imageStream
  • Fallback to member avatars when no channel image is set
  • Deterministic color assignment for member avatars

{@tool snippet}

Basic usage with a channel:

StreamChannelAvatar(channel: channel)

{@end-tool}

{@tool snippet}

With custom size:

StreamChannelAvatar(
  channel: channel,
  size: StreamAvatarGroupSize.xl,
)

{@end-tool}

Theming

StreamChannelAvatar uses StreamAvatarThemeData for default styling. Member avatars within the channel avatar use deterministic colors from StreamColorScheme.avatarPalette.

See also:

Inheritance

Constructors

StreamChannelAvatar({Key? key, StreamAvatarGroupSize? size, required Channel channel})
Creates a Stream channel avatar.
const

Properties

channel Channel
The channel whose avatar is displayed.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size StreamAvatarGroupSize?
The size of the channel avatar.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited