AttachmentBlockedError class
Returned by StreamAttachmentValidator.validate when the file's extension or MIME type is not permitted by the matching UploadConfig.
Both fileExtension and mimeType are populated regardless of which list triggered the failure.
See also:
- AttachmentTooLargeError, AttachmentLimitReachedError, for the other validator failures.
- Inheritance
-
- Object
- StreamChatError
- AttachmentBlockedError
Constructors
- AttachmentBlockedError({String? fileExtension, String? mimeType})
-
Creates a new AttachmentBlockedError.
const
Properties
- fileExtension → String?
-
The extension of the blocked attachment, if known.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message
finalinherited
- mimeType → String?
-
The MIME type of the blocked attachment, if known.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited