markUnreadByTimestamp method
Marks the channel as unread by a given timestamp.
All messages after the provided timestamp will be marked as unread.
Implementation
Future<EmptyResponse> markUnreadByTimestamp(DateTime timestamp) async {
_checkInitialized();
if (!canUseReadReceipts) {
throw const StreamChatError(
'Cannot mark as unread: Channel does not support read events. '
'Enable read_events in your channel type configuration.',
);
}
return _client.markChannelUnreadByTimestamp(id!, type, timestamp);
}