onQuotedMessageTap property
Called when a quoted message is tapped.
When provided, this callback is forwarded to each StreamMessageItem in the list.
When null (the default), tapping a quoted message scrolls to it in the list, loading it if necessary.
Implementation
final void Function(Message quotedMessage)? onQuotedMessageTap;